@@ -7,11 +7,17 @@ from django_libs.admin import MultilingualPublishMixin
 from simple_translation.admin import TranslationAdmin
 from simple_translation.utils import get_preferred_translation_from_lang
 
-from .models import Organization
+from .models import Organization, OrganizationPersonRole
+
+
+class OrganizationPersonRoleInline(admin.TabularInline):
+    """Inline admin for ``OrganizationPersonRole`` objects."""
+    model = OrganizationPersonRole
 
 
 class OrganizationAdmin(MultilingualPublishMixin, TranslationAdmin):
     """Admin for the ``Organization`` model."""
+    inlines = [OrganizationPersonRoleInline]
     list_display = ['title', 'phone', 'website', 'is_published']
 
     def title(self, obj):
